@@ -4,5 +4,5 @@ A collection of general purpose reusable utilities.
 
 
 def version():
-    return "0.8"
+    return "0.8.1"
 
